"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MindExpressionApi = void 0;
var _ErrorHandler = _interopRequireDefault(require("../utils/errors/ErrorHandler"));
var _ExpressionApi = require("../services/ExpressionApi/ExpressionApi");
var _ExpressionApi2 = require("../services/ExpressionApi/ExpressionApi.types");
var _utils = require("../utils");
var _UuidHelper = require("../utils/helpers/UuidHelper");
var _MindExpressionApi = require("./MindExpressionApi.type");
var _MyEventEmitter = _interopRequireDefault(require("../utils/customs/MyEventEmitter"));
var _errors = require("../utils/errors");
var _Logger = require("../services/Logger/Logger");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
class MindExpressionApi {
  /**Engine URL - You can get this on the integration page. This is the main URL you will use to access the API’s endpoint*/

  /**Auth Key - This is the authorization token on the integration page. This token is used to authorize your access to the Mind Expression API.*/

  /**UUID (e.g. 408b6dca-fc5e-4be7-b5a9-cfa9d6c61a3c)*/

  /**UUID (e.g. 408b6dca-fc5e-4be7-b5a9-cfa9d6c61a3c)*/

  /**UUID (e.g. 408b6dca-fc5e-4be7-b5a9-cfa9d6c61a3c)*/

  /**timestamp(milliseconds) */

  /**Splited DEVELOPER_ID from API to use later */

  /**Splited SCOPE_ID from API to use later */

  /**Instance of API query class */

  /**Map of chat messages by timestamp */

  /**Logger to log action events */

  /** */

  /**
   * Create a new Mind Expression object
   * @param engineUrl Engine URL - You can get this on the integration page. This is the main URL you will use to access the API’s endpoint
   * @param authKey Auth Key - This is the authorization token on the integration page. This token is used to authorize your access to the Mind Expression API.
   * @param deviceUinqueId Unique id of device- This will be use to save/fetch device chat history
   * @param options options to custom MindExpressionApi:
   *      - useLogger @type {boolean}: log all events or not
   */
  constructor(engineUrl, authKey, deviceUinqueId, options) {
    this.engineUrl = engineUrl;
    this.authKey = authKey;
    this.conversationId = null;
    this.currentQueryId = null;
    this.conversationDataMap = new Map();
    this.eventEmitter = new _MyEventEmitter.default();
    this.xRecipientId = deviceUinqueId ? (0, _UuidHelper.initUUID)(deviceUinqueId) : (0, _UuidHelper.initUUID)();
    if (options !== null && options !== void 0 && options.useLogger) {
      this.logger = new _Logger.Logger();
    }

    //FIXME: still not handle `readGatewayPath` errors
    try {
      var _this$logger;
      const urlData = _utils.ApiHelper.readGatewayPath(this.engineUrl);
      this.expressionApi = new _ExpressionApi.ExpressionApi(urlData.host);
      this.DEVELOPER_ID = urlData.DEVELOPER_ID;
      this.SCOPE_ID = urlData.SCOPE_ID;
      (_this$logger = this.logger) === null || _this$logger === void 0 ? void 0 : _this$logger.logEvent('init', 'succeed', urlData);
    } catch (e) {
      var _this$logger2;
      // console.log(e);
      this.expressionApi = new _ExpressionApi.ExpressionApi('');
      this.DEVELOPER_ID = '';
      this.SCOPE_ID = '';
      (_this$logger2 = this.logger) === null || _this$logger2 === void 0 ? void 0 : _this$logger2.logEvent('init', 'failed', e);
    }
  }

  /**
   *
   * Start the Conversation
   * conversationId will always set to null when call function
   * @returns object of @type {GatewayResponse} the response conversation of API
   */
  greeting = async () => {
    var _this$logger3;
    (_this$logger3 = this.logger) === null || _this$logger3 === void 0 ? void 0 : _this$logger3.logEvent('greeting', 'triggered');
    this.resetSession();
    this.currentQueryId = (0, _UuidHelper.initUUID)();
    this.currentTimestamp = _utils.DateTimeHelper.getCurrentTimestamp();
    let res;
    try {
      var _res, _res2, _this$conversationDat, _res3, _this$logger5, _res4;
      res = await this.expressionApi.getGateway(this.DEVELOPER_ID, this.SCOPE_ID, {
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${this.authKey}`,
        'X-Conversation-Id': `${this.conversationId}`,
        'X-Recipient-Id': `${this.xRecipientId}`
      }, {
        'query': null,
        'query-id': this.currentQueryId,
        'timestamp': this.currentTimestamp
      });

      // If API response with an error
      if (((_res = res) === null || _res === void 0 ? void 0 : _res.code) != null && !_errors.MIGHT_NOT_ERROR_CODES.includes((_res2 = res) === null || _res2 === void 0 ? void 0 : _res2.code)) {
        var _this$logger4;
        res = _ErrorHandler.default.handleGatewayError(res);
        (_this$logger4 = this.logger) === null || _this$logger4 === void 0 ? void 0 : _this$logger4.logEvent('greeting', 'failed', res);
        return res;
      }

      //FIXME: this is for reset messages list
      (_this$conversationDat = this.conversationDataMap) === null || _this$conversationDat === void 0 ? void 0 : _this$conversationDat.clear();
      this.updateCAIMessages(res);
      this.setSession((_res3 = res) === null || _res3 === void 0 ? void 0 : _res3['X-Conversation-Id']);
      (_this$logger5 = this.logger) === null || _this$logger5 === void 0 ? void 0 : _this$logger5.logEvent('greeting', 'succeed', (_res4 = res) === null || _res4 === void 0 ? void 0 : _res4.data);
    } catch (e) {
      var _this$logger6;
      res = _ErrorHandler.default.handleGatewayError(e);
      (_this$logger6 = this.logger) === null || _this$logger6 === void 0 ? void 0 : _this$logger6.logEvent('greeting', 'failed', res);
    }
    return res;
  };

  /**
   *
   * Restart the Conversation
   * @returns object of @type {GatewayResponse} the response conversation of API
   */
  restart = async () => {
    var _this$logger7;
    (_this$logger7 = this.logger) === null || _this$logger7 === void 0 ? void 0 : _this$logger7.logEvent('restart', 'triggered');
    this.resetSession();
    return this.greeting();
  };
  converse = async query => {
    var _this$logger8;
    (_this$logger8 = this.logger) === null || _this$logger8 === void 0 ? void 0 : _this$logger8.logEvent('converse', 'triggered');
    let res;
    // Return error if user not called start, or the conversationId is empty
    if (!this.conversationId) {
      var _this$logger9;
      res = _ErrorHandler.default.handleGatewayError(1000);
      (_this$logger9 = this.logger) === null || _this$logger9 === void 0 ? void 0 : _this$logger9.logEvent('converse', 'failed', res);
      return res;
    }
    if (!query) {
      var _this$logger10;
      res = _ErrorHandler.default.handleGatewayError(210);
      (_this$logger10 = this.logger) === null || _this$logger10 === void 0 ? void 0 : _this$logger10.logEvent('converse', 'failed', res);
      return res;
    }
    this.currentQueryId = (0, _UuidHelper.initUUID)();
    this.currentTimestamp = _utils.DateTimeHelper.getCurrentTimestamp();
    try {
      var _res5, _res6, _res7, _this$logger12, _res8;
      this.updateUserMessage(query);
      res = await this.expressionApi.getGateway(this.DEVELOPER_ID, this.SCOPE_ID, {
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${this.authKey}`,
        'X-Conversation-Id': `${this.conversationId}`,
        'X-Recipient-Id': `${this.xRecipientId}`
      }, {
        'query': query,
        'query-id': this.currentQueryId,
        'timestamp': this.currentTimestamp
      });

      // If API response with an error
      if (((_res5 = res) === null || _res5 === void 0 ? void 0 : _res5.code) != null && !_errors.MIGHT_NOT_ERROR_CODES.includes((_res6 = res) === null || _res6 === void 0 ? void 0 : _res6.code)) {
        var _this$logger11;
        res = _ErrorHandler.default.handleGatewayError(res);
        (_this$logger11 = this.logger) === null || _this$logger11 === void 0 ? void 0 : _this$logger11.logEvent('sendMessage', 'failed', res);
        return res;
      }
      this.updateCAIMessages(res);
      this.setSession((_res7 = res) === null || _res7 === void 0 ? void 0 : _res7['X-Conversation-Id']);
      (_this$logger12 = this.logger) === null || _this$logger12 === void 0 ? void 0 : _this$logger12.logEvent('converse', 'succeed', (_res8 = res) === null || _res8 === void 0 ? void 0 : _res8.data);
    } catch (e) {
      var _this$logger13;
      (_this$logger13 = this.logger) === null || _this$logger13 === void 0 ? void 0 : _this$logger13.logEvent('converse', 'failed', e);
      res = _ErrorHandler.default.handleGatewayError(e);
    }
    return res;
  };
  getLogs = () => {
    var _this$logger14;
    if (!this.logger) {
      throw (0, _errors.errorFromCode)(2000);
    }
    return (_this$logger14 = this.logger) === null || _this$logger14 === void 0 ? void 0 : _this$logger14.getLogTexts();
  };
  resetSession = () => {
    this.conversationId = null;
    this.conversationDataMap = new Map();
  };
  setSession = (() => {
    var _this = this;
    return function () {
      let newConversationId = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      _this.conversationId = newConversationId ?? null;
    };
  })();

  /// Getters
  /**Get latest conversationId. */
  getSession = () => {
    return this.conversationId;
  };
  /**Get latest query-id that is sent. */
  getQueryId = () => {
    return this.currentQueryId;
  };

  /**Get latest timestamp sent a request. */
  getTimestamp = () => {
    return this.currentTimestamp;
  };

  /// Internal functions
  updateMessageList = (newMessage, timestamp) => {
    var _this$conversationDat2;
    this.conversationDataMap.set(timestamp ?? _utils.DateTimeHelper.getCurrentTimestamp(), newMessage);
    this.eventEmitter.emit(_MindExpressionApi.MindExpressionApiEvents.NEW_MESSAGE, {
      newMessage,
      conversationData: [...((this === null || this === void 0 || (_this$conversationDat2 = this.conversationDataMap) === null || _this$conversationDat2 === void 0 ? void 0 : _this$conversationDat2.values()) ?? [])]
    });
  };
  updateUserMessage = message => {
    const data = {
      template: message
    };
    const finalTimestamp = _utils.DateTimeHelper.getCurrentTimestamp();
    this.updateMessageList({
      sender: 'User',
      data,
      timestamp: finalTimestamp
    }, finalTimestamp);
  };
  updateCAIMessages = response => {
    var _response$data;
    const channelResults = (response === null || response === void 0 || (_response$data = response.data) === null || _response$data === void 0 ? void 0 : _response$data['channel-result']) ?? [];
    for (let i = 0; i < (channelResults === null || channelResults === void 0 ? void 0 : channelResults.length); i++) {
      var _channelResult$channe, _channelResult$channe2, _channelResult$channe3, _channelResult$channe4;
      const channelResult = channelResults[i];
      const channelInstruction = this.isValidMessageObject(channelResult === null || channelResult === void 0 ? void 0 : channelResult['channel-instruction']) ? channelResult === null || channelResult === void 0 ? void 0 : channelResult['channel-instruction'] : undefined;
      const channelInstructionAlt = channelResult !== null && channelResult !== void 0 && (_channelResult$channe = channelResult['channel-instruction-alt']) !== null && _channelResult$channe !== void 0 && (_channelResult$channe = _channelResult$channe.channels) !== null && _channelResult$channe !== void 0 && _channelResult$channe.length && this.isValidMessageObject(channelResult === null || channelResult === void 0 || (_channelResult$channe2 = channelResult['channel-instruction-alt']) === null || _channelResult$channe2 === void 0 || (_channelResult$channe2 = _channelResult$channe2.channels) === null || _channelResult$channe2 === void 0 ? void 0 : _channelResult$channe2[0]) ? channelResult === null || channelResult === void 0 ? void 0 : channelResult['channel-instruction-alt'] : undefined;
      const channelMessage = this.isValidMessageObject(channelResult === null || channelResult === void 0 ? void 0 : channelResult['channel-message']) ? channelResult === null || channelResult === void 0 ? void 0 : channelResult['channel-message'] : undefined;
      const channelMessageAlt = channelResult !== null && channelResult !== void 0 && (_channelResult$channe3 = channelResult['channel-message-alt']) !== null && _channelResult$channe3 !== void 0 && (_channelResult$channe3 = _channelResult$channe3.channels) !== null && _channelResult$channe3 !== void 0 && _channelResult$channe3.length && this.isValidMessageObject(channelResult === null || channelResult === void 0 || (_channelResult$channe4 = channelResult['channel-message-alt']) === null || _channelResult$channe4 === void 0 || (_channelResult$channe4 = _channelResult$channe4.channels) === null || _channelResult$channe4 === void 0 ? void 0 : _channelResult$channe4[0]) ? channelResult === null || channelResult === void 0 ? void 0 : channelResult['channel-message-alt'] : undefined;
      console.log(channelInstruction);
      console.log(channelInstructionAlt);
      console.log(channelMessage);
      console.log(channelMessageAlt);
      if (channelInstruction) {
        const finalTimestamp = _utils.DateTimeHelper.getCurrentTimestamp();
        this.updateMessageList({
          sender: 'CAI',
          data: channelInstruction,
          timestamp: finalTimestamp
        }, finalTimestamp);
      } else if (channelInstructionAlt) {
        const finalTimestamp = _utils.DateTimeHelper.getCurrentTimestamp();
        for (let alt of channelInstructionAlt.channels) {
          this.updateMessageList({
            sender: 'CAI',
            data: alt,
            timestamp: finalTimestamp
          }, finalTimestamp);
        }
      }
      if (channelMessage) {
        const finalTimestamp = _utils.DateTimeHelper.getCurrentTimestamp();
        this.updateMessageList({
          sender: 'CAI',
          data: channelMessage,
          timestamp: finalTimestamp
        }, finalTimestamp);
      } else if (channelMessageAlt) {
        const finalTimestamp = _utils.DateTimeHelper.getCurrentTimestamp();
        for (let alt of channelMessageAlt.channels) {
          this.updateMessageList({
            sender: 'CAI',
            data: alt,
            timestamp: finalTimestamp
          }, finalTimestamp);
        }
      }
    }
  };
  isValidMessageObject(obj) {
    var _obj$cardList;
    return !!(obj !== null && obj !== void 0 && obj['template-type']) && _ExpressionApi2.TemplateTypes.includes(obj === null || obj === void 0 ? void 0 : obj['template-type']) && !!(obj !== null && obj !== void 0 && obj.template || obj !== null && obj !== void 0 && (_obj$cardList = obj['card-list']) !== null && _obj$cardList !== void 0 && _obj$cardList.length || obj !== null && obj !== void 0 && obj['image-url'] || obj !== null && obj !== void 0 && obj.datetime);
  }
}
exports.MindExpressionApi = MindExpressionApi;
//# sourceMappingURL=MindExpressionApi.js.map