"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FirebaseStorageService = void 0;
var _utils = require("../../utils");
var _RemoteStorageService = require("./RemoteStorageService");
var _app = require("firebase/app");
var _storage = require("firebase/storage");
class FirebaseStorageService extends _RemoteStorageService.RemoteStorageService {
  constructor(config) {
    super();
    this.app = (0, _app.initializeApp)(config.options);
    this.fbStorage = (0, _storage.getStorage)();
    this.rootPath = this.buildRootPath(config.rootDirectory);
  }
  uploadFile = async (path, uploadFileName) => {
    try {
      const blob = await _utils.FileHelper.uriToBlob(path);

      // Reference of file to upload
      const fileRef = (0, _storage.ref)(this.fbStorage, this.buildFilePath(uploadFileName));
      //Upload the file. Use uploadTask for if we want to control upload in the future
      const uploadTask = (0, _storage.uploadBytesResumable)(fileRef, blob);
      const result = await uploadTask;
      console.log(result);
      return await (0, _storage.getDownloadURL)(fileRef);
    } catch (e) {
      console.log(e);
      return '';
    }
  };

  ///Private functions
  buildRootPath = name => {
    // Root is `/`
    if (!name) {
      return '';
    }

    // Root is `/name/`
    if (!name.startsWith('/') && !name.startsWith('\\')) {
      name = '/' + name;
    }
    if (!name.endsWith('/') && !name.endsWith('\\')) {
      name = name + '/';
    }
    return name;
  };
  buildFilePath = fileName => {
    return `${this.rootPath}${fileName}`;
  };
}
exports.FirebaseStorageService = FirebaseStorageService;
//# sourceMappingURL=FirebaseStorageService.js.map