"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UnauthorizedError = exports.QueryIdDuplicatedError = exports.NotClassifiedError = exports.MIGHT_NOT_ERROR_CODES = exports.LoggerNotExistError = exports.InternalServerError = exports.ErrorWithCode = exports.EmptyInputMessageError = exports.ConversationTerminatedError = exports.ConversationNotStartedError = exports.BadRequestError = void 0;
exports.errorFromCode = errorFromCode;
exports.errorFromName = errorFromName;
const errorMapByCode = new Map();
const errorMapByName = new Map();
class ErrorWithCode extends Error {}
exports.ErrorWithCode = ErrorWithCode;
/**
 * ConversationNotStartedError: Conversation not started
 *
 * @category Errors
 * @category generated
 */
class ConversationNotStartedError extends ErrorWithCode {
  code = 1000;
  name = ConversationNotStartedError.name;
  constructor() {
    super('Conversation not started');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, ConversationNotStartedError);
    }
  }
}
exports.ConversationNotStartedError = ConversationNotStartedError;
errorMapByCode.set(1000, () => new ConversationNotStartedError());
errorMapByName.set(ConversationNotStartedError.name, () => new ConversationNotStartedError());

/**
 * LoggerNotExistError: Logger not existed, please try enable it
 *
 * @category Errors
 * @category generated
 */
class LoggerNotExistError extends ErrorWithCode {
  code = 2000;
  name = LoggerNotExistError.name;
  constructor() {
    super('Logger not existed, please try enable it');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, LoggerNotExistError);
    }
  }
}
exports.LoggerNotExistError = LoggerNotExistError;
errorMapByCode.set(2000, () => new LoggerNotExistError());
errorMapByName.set(LoggerNotExistError.name, () => new LoggerNotExistError());

/**
 * NotClassifiedError: The Mind Expression engine does not understand the message
 * within the conversation configurations.
 *
 * @category Errors
 * @category generated
 */
class NotClassifiedError extends ErrorWithCode {
  code = 204;
  name = NotClassifiedError.name;
  constructor() {
    super('The Mind Expression engine does not understand the message within the conversation configurations.');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, NotClassifiedError);
    }
  }
}
exports.NotClassifiedError = NotClassifiedError;
errorMapByCode.set(204, () => new NotClassifiedError());
errorMapByName.set(NotClassifiedError.name, () => new NotClassifiedError());

/**
 * EmptyInputMessageError: Conversation not started
 *
 * @category Errors
 * @category generated
 */
class EmptyInputMessageError extends ErrorWithCode {
  code = 210;
  name = EmptyInputMessageError.name;
  constructor() {
    super('Empty input message');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, EmptyInputMessageError);
    }
  }
}
exports.EmptyInputMessageError = EmptyInputMessageError;
errorMapByCode.set(210, () => new EmptyInputMessageError());
errorMapByName.set(EmptyInputMessageError.name, () => new EmptyInputMessageError());

/**
 * ConversationTerminatedError: The message and response ends the current conversation.
 *
 * @category Errors
 * @category generated
 */
class ConversationTerminatedError extends ErrorWithCode {
  code = 220;
  name = ConversationTerminatedError.name;
  constructor() {
    super('The message and response ends the current conversation.');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, ConversationTerminatedError);
    }
  }
}
exports.ConversationTerminatedError = ConversationTerminatedError;
errorMapByCode.set(220, () => new ConversationTerminatedError());
errorMapByName.set(ConversationTerminatedError.name, () => new ConversationTerminatedError());

/**
 * BadRequestError: Authorization or request data wrong, please check again.
 *
 * @category Errors
 * @category generated
 */
class BadRequestError extends ErrorWithCode {
  code = 400;
  name = BadRequestError.name;
  constructor() {
    super('Request data wrong, please check again.');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, BadRequestError);
    }
  }
}
exports.BadRequestError = BadRequestError;
errorMapByCode.set(400, () => new BadRequestError());
errorMapByName.set(BadRequestError.name, () => new BadRequestError());

/**
 * UnauthorizedError: Unauthorized.
 *
 * @category Errors
 * @category generated
 */
class UnauthorizedError extends ErrorWithCode {
  code = 401;
  name = UnauthorizedError.name;
  constructor() {
    super('Unauthorized');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, UnauthorizedError);
    }
  }
}
exports.UnauthorizedError = UnauthorizedError;
errorMapByCode.set(401, () => new UnauthorizedError());
errorMapByName.set(UnauthorizedError.name, () => new UnauthorizedError());

/**
 * QueryIdDuplicatedError: query-id is duplicated.
 *
 * @category Errors
 * @category generated
 */
class QueryIdDuplicatedError extends ErrorWithCode {
  code = 409;
  name = UnauthorizedError.name;
  constructor() {
    super('query-id is duplicated');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, QueryIdDuplicatedError);
    }
  }
}
exports.QueryIdDuplicatedError = QueryIdDuplicatedError;
errorMapByCode.set(409, () => new QueryIdDuplicatedError());
errorMapByName.set(QueryIdDuplicatedError.name, () => new QueryIdDuplicatedError());

/**
 * InternalServerError: Internal server error.
 *
 * @category Errors
 * @category generated
 */
class InternalServerError extends ErrorWithCode {
  code = 500;
  name = InternalServerError.name;
  constructor() {
    super('Internal server error.');
    if (typeof Error.captureStackTrace === 'function') {
      Error.captureStackTrace(this, InternalServerError);
    }
  }
}
exports.InternalServerError = InternalServerError;
errorMapByCode.set(500, () => new InternalServerError());
errorMapByName.set(InternalServerError.name, () => new InternalServerError());

/**
 * Attempts to resolve a custom error from the provided error code.
 * @category Errors
 * @category generated
 */
function errorFromCode(code) {
  const createError = errorMapByCode.get(code);
  return createError != null ? createError() : null;
}

/**
 * Attempts to resolve a custom error from the provided error name
 * @category Errors
 * @category generated
 */
function errorFromName(name) {
  const createError = errorMapByName.get(name);
  return createError != null ? createError() : null;
}
const MIGHT_NOT_ERROR_CODES = [200, 201, 202, 204, 220];
exports.MIGHT_NOT_ERROR_CODES = MIGHT_NOT_ERROR_CODES;
//# sourceMappingURL=index.js.map