"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toMoment = exports.msToHMS = exports.isBetween = exports.getHourByPeriod = exports.getCurrentTimestamp = exports.formatMindXDatetime = exports.formatDate = exports.MINDX_DATE_TIME_SEPARATOR = void 0;
var _moment = _interopRequireDefault(require("moment"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const getCurrentTimestamp = function () {
  let isUTC = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
  const now = new Date();
  if (isUTC) {
    const utcDate = Date.UTC(now.getUTCFullYear(), now.getUTCMonth(), now.getUTCDate(), now.getUTCHours(), now.getUTCMinutes(), now.getUTCSeconds(), now.getUTCMilliseconds());
    return utcDate.valueOf();
  }
  return now.valueOf();
};
exports.getCurrentTimestamp = getCurrentTimestamp;
const toMoment = (date, format) => {
  if (!date) {
    return undefined;
  }
  return typeof date === 'string' || format ? (0, _moment.default)(date, format ?? 'YYYY/MM/DD') //FIXME: use common format
  : (0, _moment.default)(date);
};
exports.toMoment = toMoment;
const formatDate = (date, format) => {
  if (!date) {
    return undefined;
  }
  const mDate = toMoment(date);
  return mDate === null || mDate === void 0 ? void 0 : mDate.format(format ?? 'LL');
};
exports.formatDate = formatDate;
const getHourByPeriod = time => {
  return {
    hours: time.getHours() % 12 || 12,
    minutes: time.getMinutes(),
    seconds: time.getSeconds(),
    period: time.getHours() < 12 ? 'AM' : 'PM'
  };
};
exports.getHourByPeriod = getHourByPeriod;
const msToHMS = ms => {
  // 1- Convert to seconds:
  let seconds = ms / 1000;
  // 2- Extract hours:
  const hours = Math.round(seconds / 3600); // 3,600 seconds in 1 hour
  seconds = seconds % 3600; // seconds remaining after extracting hours
  // 3- Extract minutes:
  const minutes = Math.round(seconds / 60); // 60 seconds in 1 minute
  // 4- Keep only seconds not extracted to minutes:
  seconds = Math.round(seconds % 60);
  const timeParts = [];
  if (hours) {
    timeParts.push(hours >= 10 ? `${hours}` : `0${hours}`);
  }
  timeParts.push(minutes >= 10 ? `${minutes}` : `0${minutes}`);
  timeParts.push(seconds >= 10 ? `${seconds}` : `0${seconds}`);
  return timeParts === null || timeParts === void 0 ? void 0 : timeParts.join(':');
};
exports.msToHMS = msToHMS;
const isBetween = (date, startDate, endDate) => {
  if (!date) {
    return undefined;
  }
  const mDate = typeof date === 'string' ? (0, _moment.default)(date, 'YYYY/MM/DD') //FIXME: use common format
  : (0, _moment.default)(date);
  const mStart = startDate ? typeof startDate === 'string' ? (0, _moment.default)(startDate, 'YYYY/MM/DD') //FIXME: use common format
  : (0, _moment.default)(startDate) : undefined;
  const mEnd = endDate ? typeof endDate === 'string' ? (0, _moment.default)(endDate, 'YYYY/MM/DD') //FIXME: use common format
  : (0, _moment.default)(endDate) : undefined;
  return (!mStart || mDate.isSameOrAfter(mStart)) && (!mEnd || mDate.isSameOrBefore(mEnd));
};
exports.isBetween = isBetween;
const formatMindXDatetime = (datetime, endDate, pickerProps, options) => {
  var _datetime$valueOf;
  let finalStr = '';
  let format = (pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps.format) ?? 'YYYY/MM/DD';

  // change to moment format type
  format = format.replace(/AM\/PM/g, 'A');

  //Handle specials chars
  if (format.includes('오전/오후')) {
    format = format.replace(/오전\/오후/g, 'A[.k]');
  }
  format = format.replace(/HH:MM/g, format.includes('A') ? 'hh:mm' : 'HH:mm');
  if (datetime !== null && datetime !== void 0 && (_datetime$valueOf = datetime.valueOf) !== null && _datetime$valueOf !== void 0 && _datetime$valueOf.call(datetime)) {
    let mDateStr = (0, _moment.default)(datetime).format(format);
    let mEndDateStr = endDate ? (0, _moment.default)(endDate).format(format) : '';
    if ((pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps.type) === 'date_range') {
      var _ref;
      finalStr = (_ref = [mDateStr, mEndDateStr]) === null || _ref === void 0 || (_ref = _ref.filter(it => !!it)) === null || _ref === void 0 ? void 0 : _ref.join(' - ');
    } else {
      finalStr = mDateStr;
    }

    //Reformat back special chars
    finalStr = finalStr.replace(/AM.k/g, '오전').replace(/PM.k/g, '오후');
  }
  if (options !== null && options !== void 0 && options.isDateOnly) {
    var _finalStr;
    return ((_finalStr = finalStr) === null || _finalStr === void 0 || (_finalStr = _finalStr.split(MINDX_DATE_TIME_SEPARATOR)) === null || _finalStr === void 0 ? void 0 : _finalStr[0]) ?? '';
  } else if (options !== null && options !== void 0 && options.isTimeOnly) {
    var _finalStr2;
    return ((_finalStr2 = finalStr) === null || _finalStr2 === void 0 || (_finalStr2 = _finalStr2.split(MINDX_DATE_TIME_SEPARATOR)) === null || _finalStr2 === void 0 ? void 0 : _finalStr2[1]) ?? '';
  }
  return finalStr;
};
exports.formatMindXDatetime = formatMindXDatetime;
const MINDX_DATE_TIME_SEPARATOR = ', ';
exports.MINDX_DATE_TIME_SEPARATOR = MINDX_DATE_TIME_SEPARATOR;
//# sourceMappingURL=DateTimeHelper.js.map