import React, { useEffect, useState } from 'react';
import { StyleSheet, Text, View } from 'react-native';
import { FileHelper, StringHelper, s, st } from '../../utils';
import SvgCustomFile from '../../assets/png/ReactSvgs/SvgCustomFile';
import colors from '../../utils/theme/colors';
import { isIOS } from '../../utils/constants/constants';
import Spacer from '../CustomView/Spacer';
import queryString from 'query-string';
const CustomFile = _ref => {
  let {
    ...restProps
  } = _ref;
  //States
  const [fileSize, setFileSize] = useState('calculating...');
  //Vars that used multi times
  const {
    position,
    currentMessage
  } = restProps;
  //use queryString is to prevent Url with queries
  const pathReader = queryString.parseUrl((currentMessage === null || currentMessage === void 0 ? void 0 : currentMessage.file) ?? '');
  const filename = StringHelper.getFileName((pathReader === null || pathReader === void 0 ? void 0 : pathReader.url) ?? '');
  const ext = StringHelper.getFileExtensions((pathReader === null || pathReader === void 0 ? void 0 : pathReader.url) ?? '');
  const isLeft = position === 'left';
  //Effects
  useEffect(() => {
    var _currentMessage$file;
    if (currentMessage !== null && currentMessage !== void 0 && (_currentMessage$file = currentMessage.file) !== null && _currentMessage$file !== void 0 && (_currentMessage$file = _currentMessage$file.toLowerCase()) !== null && _currentMessage$file !== void 0 && _currentMessage$file.startsWith('http')) {
      fetchFileSize(currentMessage === null || currentMessage === void 0 ? void 0 : currentMessage.file);
    }
  }, [currentMessage]);
  const fetchFileSize = async path => {
    const blob = await FileHelper.uriToBlob(path);
    setFileSize(StringHelper.getFileSize(blob.size));
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(SvgCustomFile, {
    fileExtensions: ext
  }), /*#__PURE__*/React.createElement(Spacer, {
    width: 16
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.textContainer
  }, /*#__PURE__*/React.createElement(Text, {
    style: [styles.fileName, {
      color: isLeft ? colors.shark : colors.white
    }],
    numberOfLines: 1,
    ellipsizeMode: 'middle'
  }, filename), /*#__PURE__*/React.createElement(Text, {
    style: [styles.fileSize, {
      color: isLeft ? colors.grayChateau : colors.white
    }],
    numberOfLines: 1,
    ellipsizeMode: 'middle'
  }, fileSize ? fileSize : 'calculating...')), /*#__PURE__*/React.createElement(Spacer, {
    width: 40
  }));
};
export default CustomFile;
const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    margin: st(5)
  },
  textContainer: {
    width: s(104)
  },
  fileName: {
    color: colors.shark,
    fontWeight: isIOS ? '600' : 'bold',
    fontSize: st(12),
    lineHeight: st(16),
    letterSpacing: -0.02
  },
  fileSize: {
    color: colors.grayChateau,
    fontWeight: isIOS ? '400' : 'normal',
    fontSize: st(10),
    lineHeight: st(14),
    letterSpacing: -0.02
  }
});
//# sourceMappingURL=CustomFile.js.map