import React, { useEffect, useState } from 'react';
import { StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import colors from '../../../utils/theme/colors';
import { DateTimeHelper, s, st, vs } from '../../../utils';
import Spacer from '../Spacer';
import { isIOS } from '../../../utils/constants/constants';
import { Calendar, LocaleConfig } from 'react-native-calendars';
import moment from 'moment';
import CustomTimeDropdown from './components/CustomTimeDropdown';
import { translate } from '../../../i18n';
const CustomDateTimePicker = _ref => {
  let {
    pickerProps,
    onConfirm,
    ...restProps
  } = _ref;
  const todayMoment = moment();
  const minDateMoment = DateTimeHelper.toMoment(pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps['min-date']);
  const maxDateMoment = DateTimeHelper.toMoment(pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps['max-date']);
  //States
  const [date, setDate] = useState();
  // pickerProps?.type === 'date_range' ||
  //   (pickerProps?.['date-limit-type'] === 'future_only' &&
  //   !pickerProps?.['include-current-date']) ||
  //     (pickerProps?.['date-limit-type'] === 'limited' &&
  //     !DateTimeHelper.isBetween(new Date(), minDateMoment?.toDate(), maxDateMoment?.toDate()))
  //   ? undefined
  //   : new Date()
  const [endDate, setEndDate] = useState();
  const [time, setTime] = useState(moment().set({
    hour: 1,
    minute: 0,
    second: 0,
    millisecond: 0
  }).toDate());
  const [dateError, setDateError] = useState('');
  const [timeError, setTimeError] = useState('');

  //Variables that uses multiple times
  const showPickDate = ['date', 'datetime', 'date_range'].includes(pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps.type);
  const showPickTime = ['datetime', 'time'].includes(pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps.type);
  const isDateRange = (pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps.type) === 'date_range';
  const timeParts = DateTimeHelper.getHourByPeriod(time);
  const locale = pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps.language;

  //Effects
  useEffect(() => {
    //Update minutes to nearest minutes in selection
    time.setMinutes((minutes === null || minutes === void 0 ? void 0 : minutes.find(it => it >= (timeParts === null || timeParts === void 0 ? void 0 : timeParts.minutes))) ?? 0);
    setTime(new Date(time));
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  //Functions
  const handleDateSelect = day => {
    const mDay = moment(day === null || day === void 0 ? void 0 : day.timestamp);
    const mStart = date ? moment(date) : undefined;
    const mEnd = endDate ? moment(endDate) : undefined;
    setDateError('');

    //Case 1: Pick 1 date only
    if (!isDateRange) {
      if (!date || !(mDay !== null && mDay !== void 0 && mDay.isSame(mStart))) {
        setDate(new Date(day.timestamp));
      } else {
        setDate(undefined);
      }
      return;
    }
    // Case 2: Pick date range
    if (!date) {
      setDate(mDay.toDate());
    } else if (!endDate) {
      if (mDay.isSameOrBefore(mStart, 'd')) {
        setEndDate(mStart === null || mStart === void 0 ? void 0 : mStart.toDate());
        setDate(mDay.toDate());
      } else {
        setEndDate(mDay.toDate());
      }
    } else {
      if (mDay.isSame(mStart, 'd')) {
        setDate(undefined);
        setEndDate(undefined);
      } else if (mDay.isSame(mEnd, 'd')) {
        setDate(mDay.toDate());
        setEndDate(undefined);
      } else if (mDay.isAfter(mStart, 'd')) {
        setEndDate(mDay.toDate());
      } else {
        setDate(mDay.toDate());
      }
    }
  };
  const handleConfirm = () => {
    const finalDate = date ? moment(date) : moment();
    if (isDateRange && (!date || !endDate)) {
      setDateError(translate('please_select_a_valid_date_range', undefined, locale));
      return;
    } else if (showPickDate && !date) {
      setDateError(translate('please_select_a_date', undefined, locale));
      return;
    } else if (showPickTime && !time) {
      setDateError(translate('please_select_a_valid_time', undefined, locale));
      return;
    }
    if (time) {
      finalDate.hour(time.getHours());
      finalDate.minute(time.getMinutes());
      finalDate.second(time.getSeconds());
    }
    onConfirm === null || onConfirm === void 0 ? void 0 : onConfirm(finalDate.toDate(), endDate);
  };
  const renderCommonTextGroup = function (label) {
    let content = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    let customPrefixContent = arguments.length > 2 ? arguments[2] : undefined;
    return /*#__PURE__*/React.createElement(View, {
      style: styles.columnContainer
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.label
    }, label), /*#__PURE__*/React.createElement(View, {
      style: styles.row
    }, customPrefixContent, /*#__PURE__*/React.createElement(Text, {
      style: styles.description
    }, content)));
  };
  const renderSelectedDate = () => {
    return /*#__PURE__*/React.createElement(View, {
      style: styles.rowContainer
    }, showPickDate ? renderCommonTextGroup(translate(isDateRange ? 'start_date' : 'selected_date', undefined, locale), date ? DateTimeHelper.formatMindXDatetime(date, undefined, pickerProps, {
      isDateOnly: true
    }) ?? '-' : '-') : undefined, showPickDate ? /*#__PURE__*/React.createElement(Spacer, {
      width: 10
    }) : undefined, showPickTime ? renderCommonTextGroup(translate('selected_time', undefined, locale), time ? translate(`time_${DateTimeHelper.formatDate(time, 'A') ?? ''}`, {
      time: DateTimeHelper.formatDate(time, 'hh:mm ') ?? ''
    }, locale) : '_') : isDateRange ? renderCommonTextGroup(translate('end_date', undefined, locale), endDate ? DateTimeHelper.formatMindXDatetime(endDate, undefined, pickerProps, {
      isDateOnly: true
    }) ?? '-' : '-') : undefined);
  };
  const renderCalendar = () => {
    //Language
    const calendarLang = locale ? locale : 'en';
    if (calendarLang) {
      LocaleConfig.locales[calendarLang] = translate('calendar_format', undefined, calendarLang);
      LocaleConfig.defaultLocale = calendarLang;
    }
    //Start/end dates
    const mStart = date ? moment(date) : undefined;
    const mEnd = endDate ? moment(endDate) : undefined;

    //Date selection limit
    const mToday = moment();
    const minDateStr = (pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps['date-limit-type']) === 'future_only' ? DateTimeHelper.formatDate(pickerProps !== null && pickerProps !== void 0 && pickerProps['include-current-date'] ? mToday.toDate() : mToday.add(1, 'd').toDate(), 'YYYY-MM-DD') : (pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps['date-limit-type']) === 'limited' && pickerProps !== null && pickerProps !== void 0 && pickerProps['min-date'] ? minDateMoment === null || minDateMoment === void 0 ? void 0 : minDateMoment.format('YYYY-MM-DD') : undefined;
    const maxDateStr = (pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps['date-limit-type']) === 'limited' && pickerProps !== null && pickerProps !== void 0 && pickerProps['max-date'] ? maxDateMoment === null || maxDateMoment === void 0 ? void 0 : maxDateMoment.format('YYYY-MM-DD') : undefined;

    //Marking renders
    var markedDates = {};
    if (mStart) {
      if (isDateRange) {
        markedDates[mStart.format('YYYY-MM-DD')] = {
          startingDay: false,
          endingDay: false,
          // !mEnd || mStart?.isSame(mEnd, 'd'),
          selected: true,
          disableTouchEvent: false,
          color: colors.earlyDawn,
          textColor: colors.white,
          customContainerStyle: {
            borderRadius: st(20),
            width: st(36),
            height: st(36),
            backgroundColor: colors.butterCup,
            marginRight: st(isIOS ? 4 : 6.8)
          }
        };
      } else {
        markedDates[mStart.format('YYYY-MM-DD')] = {
          selected: true,
          disableTouchEvent: false,
          selectedColor: colors.butterCup,
          selectedTextColor: colors.white,
          startingDay: true,
          endingDay: true,
          color: colors.butterCup,
          textColor: colors.white
        };
      }
    }
    if (mEnd) {
      markedDates[mEnd.format('YYYY-MM-DD')] = {
        startingDay: false,
        // mStart?.isSame(mEnd, 'd'),
        endingDay: false,
        selected: true,
        disableTouchEvent: false,
        color: colors.earlyDawn,
        textColor: colors.white,
        customContainerStyle: {
          borderRadius: st(20),
          width: st(36),
          height: st(36),
          backgroundColor: colors.butterCup
        }
      };
    }
    for (var m = moment(mStart).add(1, 'd'); mEnd && m !== null && m !== void 0 && m.isBefore(mEnd, 'd'); m === null || m === void 0 ? void 0 : m.add(1, 'd')) {
      markedDates[m.format('YYYY-MM-DD')] = {
        color: colors.earlyDawn,
        startingDay: false,
        endingDay: false
      };
    }
    return /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(View, {
      style: styles.separator
    }), /*#__PURE__*/React.createElement(Calendar, {
      key: `calendar-${locale}`,
      theme: {
        'arrowColor': colors.shark,
        'textMonthFontWeight': 'bold',
        'textMonthFontSize': st(12),
        'monthTextColor': colors.shark,
        'textDayHeaderFontWeight': 'bold',
        'textDayHeaderFontSize': st(12),
        'dayTextColor': colors.black,
        'todayTextColor': colors.black,
        //FIXME: this will be overrided by below
        'todayButtonFontWeight': 'bold',
        //@ts-ignore
        'stylesheet.day.basic': {
          todayText: {
            fontWeight: 'bold',
            color: colors.black
          }
        },
        //@ts-ignore
        'stylesheet.day.period': {
          todayText: {
            fontWeight: 'bold',
            color: colors.black
          }
        }
      },
      initialDate: date ? DateTimeHelper.formatDate(date, 'YYYY-MM-DD') : undefined,
      onDayPress: day => {
        handleDateSelect(day);
      },
      monthFormat: locale === 'en' ? 'yyyy.M' : undefined,
      markedDates: markedDates,
      markingType: isDateRange ? 'period' : 'dot',
      minDate: minDateStr,
      maxDate: maxDateStr,
      hideArrows: (minDateMoment === null || minDateMoment === void 0 ? void 0 : minDateMoment.isSame(todayMoment, 'month')) && (maxDateMoment === null || maxDateMoment === void 0 ? void 0 : maxDateMoment.isSame(todayMoment, 'month'))
    }), dateError ? /*#__PURE__*/React.createElement(Text, {
      style: styles.errorText
    }, dateError) : undefined);
  };
  const renderTimePicker = () => {
    const isPM = (timeParts === null || timeParts === void 0 ? void 0 : timeParts.period) === 'PM';
    return /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(View, {
      style: styles.separator
    }), /*#__PURE__*/React.createElement(Text, {
      style: styles.subTitle
    }, translate('time', undefined, locale)), /*#__PURE__*/React.createElement(View, {
      style: styles.rowContainer
    }, /*#__PURE__*/React.createElement(CustomTimeDropdown, {
      data: hours,
      locale: locale,
      defaultValue: timeParts === null || timeParts === void 0 ? void 0 : timeParts.hours,
      selectedRowStyle: styles.selectedRow,
      onSelect: (selectedItem, _index) => {
        setTimeError('');
        time.setHours(isPM && selectedItem !== 12 ? selectedItem + 12 : !isPM && selectedItem === 12 ? 0 : selectedItem);
        setTime(new Date(time));
      }
    }), /*#__PURE__*/React.createElement(CustomTimeDropdown, {
      data: minutes,
      locale: locale,
      defaultValue: timeParts === null || timeParts === void 0 ? void 0 : timeParts.minutes,
      selectedRowStyle: styles.selectedRow,
      onSelect: (selectedItem, _index) => {
        setTimeError('');
        time.setMinutes(selectedItem);
        setTime(new Date(time));
      }
    }), /*#__PURE__*/React.createElement(CustomTimeDropdown, {
      data: timePeriod,
      locale: locale,
      defaultValue: timeParts === null || timeParts === void 0 ? void 0 : timeParts.period,
      onSelect: (selectedItem, _index) => {
        setTimeError('');
        time === null || time === void 0 ? void 0 : time.setHours(selectedItem === 'PM' && (timeParts === null || timeParts === void 0 ? void 0 : timeParts.hours) !== 12 ? (timeParts === null || timeParts === void 0 ? void 0 : timeParts.hours) + 12 : selectedItem === 'AM' && (timeParts === null || timeParts === void 0 ? void 0 : timeParts.hours) === 12 ? 0 : timeParts === null || timeParts === void 0 ? void 0 : timeParts.hours);
        setTime(new Date(time));
      }
    })), timeError ? /*#__PURE__*/React.createElement(Text, {
      style: styles.errorText
    }, timeError) : undefined);
  };
  const renderButton = () => {
    // || showPickDate && !date || showPickTime && !time //=> never happen since `date` and `time` have initial value
    return /*#__PURE__*/React.createElement(TouchableOpacity
    // disabled={isDisabled}
    , {
      style: [styles.button],
      onPress: () => {
        handleConfirm === null || handleConfirm === void 0 ? void 0 : handleConfirm();
      }
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.buttonText
    }, (pickerProps === null || pickerProps === void 0 ? void 0 : pickerProps['button-label']) ?? 'Confirm'));
  };
  return /*#__PURE__*/React.createElement(View, restProps, renderSelectedDate(), showPickDate ? renderCalendar() : undefined, showPickTime ? renderTimePicker() : undefined, /*#__PURE__*/React.createElement(Spacer, {
    height: 10
  }), renderButton(), /*#__PURE__*/React.createElement(Spacer, {
    height: 16
  }));
};
export default CustomDateTimePicker;
const styles = StyleSheet.create({
  rowContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center'
  },
  row: {
    flexDirection: 'row',
    alignItems: 'center'
  },
  columnContainer: {
    width: '50%',
    flexDirection: 'column',
    justifyContent: 'flex-start',
    alignItems: 'flex-start',
    paddingBottom: s(6)
  },
  label: {
    fontWeight: isIOS ? '700' : 'bold',
    fontSize: s(12),
    color: colors.edward,
    letterSpacing: -0.02,
    textAlign: 'left',
    textAlignVertical: 'center'
  },
  subTitle: {
    fontWeight: isIOS ? '600' : 'bold',
    fontSize: st(12),
    color: colors.shark,
    letterSpacing: -0.02,
    alignSelf: 'flex-start',
    textAlign: 'center',
    textAlignVertical: 'center',
    marginVertical: vs(8)
  },
  description: {
    fontWeight: isIOS ? '700' : 'bold',
    fontSize: st(14),
    color: colors.shark,
    letterSpacing: -0.02,
    textAlign: 'center',
    textAlignVertical: 'center'
  },
  errorText: {
    fontWeight: isIOS ? '500' : 'normal',
    fontSize: st(14),
    color: colors.redOrange,
    letterSpacing: -0.02,
    textAlign: 'left',
    textAlignVertical: 'center'
  },
  separator: {
    height: 1,
    width: '100%',
    backgroundColor: colors.blueBayoux20,
    marginVertical: vs(4)
  },
  selectedRow: {
    backgroundColor: colors.earlyDawn
  },
  button: {
    // flex: 1,
    minWidth: s(120),
    borderRadius: st(2),
    padding: st(10),
    backgroundColor: colors.mountainMeadow,
    alignSelf: 'center',
    justifyContent: 'center',
    alignItems: 'center'
  },
  buttonText: {
    fontSize: st(16),
    color: colors.white,
    textAlign: 'center',
    textAlignVertical: 'center'
  }
});
const hours = [...Array(12).keys()].map(it => it += 1); // start from 1 to 12
const minutes = [...Array(60).keys()].filter(it => it % 5 === 0);
const timePeriod = ['AM', 'PM'];
//# sourceMappingURL=CustomDateTimePicker.js.map