import React, { forwardRef, useEffect, useImperativeHandle, useState } from 'react';
import { Image, Platform, StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import { st, vs } from '../../../utils/scaler';
import PopupManager from './RecorderPlayerResponsiveManager';
import colors from '../../../utils/theme/colors';
import { isIOS } from '../../../utils/constants/constants';
import images from '../../../utils/theme/image';
import Spacer from '../Spacer';
import AudioRecorderPlayer, { AudioEncoderAndroidType, AudioSourceAndroidType, AVEncoderAudioQualityIOSType, AVEncodingOption, OutputFormatAndroidType } from 'react-native-audio-recorder-player';
import { DateTimeHelper } from '../../../utils';
import RNBlobUtil from 'react-native-blob-util';
const RecorderPlayerResponsivePopup = (_props, ref) => {
  var _RNBlobUtil$fs;
  //States
  const [audioRecorderPlayer] = useState(new AudioRecorderPlayer());
  const [isVisible, setIsVisible] = useState(false);
  const [showProps, setShowProps] = useState();
  const [recordMillis, setRecordMillis] = useState(0);
  const {
    // type,
    // initialUrl,
    position,
    positionAt,
    onClose,
    extraButtonUI,
    onExtraButtonPress
  } = showProps ?? {};
  // variables that use multiple times
  audioRecorderPlayer.setSubscriptionDuration(0.1);
  var path = Platform.select({
    ios: 'sound.m4a',
    android: `${RNBlobUtil === null || RNBlobUtil === void 0 || (_RNBlobUtil$fs = RNBlobUtil.fs) === null || _RNBlobUtil$fs === void 0 || (_RNBlobUtil$fs = _RNBlobUtil$fs.dirs) === null || _RNBlobUtil$fs === void 0 ? void 0 : _RNBlobUtil$fs.CacheDir}/sound.mp3`
  });
  useImperativeHandle(ref, () => ({
    showPopup,
    togglePopup,
    hidePopup
  }));
  useEffect(() => {
    const passData = {
      showPopup,
      togglePopup,
      hidePopup
    };
    PopupManager.register(passData);
    return function cleanUp() {
      PopupManager.unregister(passData);
    };
  });
  const togglePopup = () => {
    setIsVisible(prev => !prev);
  };
  const showPopup = showPopupProps => {
    setIsVisible(true);
    setShowProps(showPopupProps);
    if ((showPopupProps === null || showPopupProps === void 0 ? void 0 : showPopupProps.type) === 'record') {
      handleStartRecord();
    }
  };
  const hidePopup = () => {
    setIsVisible(false);
    return;
  };
  const selectPosition = () => {
    if (positionAt) {
      return {
        position: 'absolute',
        ...positionAt
      };
    }
    switch (position) {
      case 'topCenter':
        {
          return styles.absoluteTopCenter;
        }
      case 'bottomCenter':
        {
          return styles.absoluteBottomCenter;
        }
      case 'center':
      default:
        {
          return styles.absoluteCenter;
        }
    }
  };
  const handleStartRecord = async () => {
    const audioSet = {
      AudioEncoderAndroid: AudioEncoderAndroidType.AAC,
      AudioSourceAndroid: AudioSourceAndroidType.MIC,
      AVEncoderAudioQualityKeyIOS: AVEncoderAudioQualityIOSType.high,
      AVNumberOfChannelsKeyIOS: 2,
      AVFormatIDKeyIOS: AVEncodingOption.aac,
      OutputFormatAndroid: OutputFormatAndroidType.AAC_ADTS
    };
    audioRecorderPlayer.addRecordBackListener(e => {
      // console.log('record-back', e);
      setRecordMillis(e === null || e === void 0 ? void 0 : e.currentPosition);
    });
    const uri = await (audioRecorderPlayer === null || audioRecorderPlayer === void 0 ? void 0 : audioRecorderPlayer.startRecorder(path, audioSet));
    console.log(`uri: ${uri}`);
  };
  const handleStopRecord = async isClose => {
    audioRecorderPlayer.removeRecordBackListener();
    const result = await audioRecorderPlayer.stopRecorder();
    setRecordMillis(0);
    console.log(result);

    //Close popup
    hidePopup();
    onClose === null || onClose === void 0 ? void 0 : onClose(isClose ? undefined : result);
  };
  const renderContent = () => {
    return /*#__PURE__*/React.createElement(View, {
      style: [styles.container, selectPosition()]
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.rowContainer
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.text
    }, DateTimeHelper.msToHMS(recordMillis)), /*#__PURE__*/React.createElement(Image, {
      source: images.ic_record_line,
      style: styles.recordLineImage
    })), /*#__PURE__*/React.createElement(Spacer, {
      height: 16
    }), /*#__PURE__*/React.createElement(View, {
      style: styles.rowContainer
    }, /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: () => {
        handleStopRecord(true);
      }
    }, /*#__PURE__*/React.createElement(Image, {
      source: images.ic_trash_bin,
      resizeMode: 'contain',
      style: styles.imageTrashBtn
    })), /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: () => {
        handleStopRecord();
      }
    }, /*#__PURE__*/React.createElement(Image, {
      source: images.ic_stop_play,
      resizeMode: 'contain',
      style: styles.imageRecordButton
    })), extraButtonUI ? /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: () => {
        onExtraButtonPress === null || onExtraButtonPress === void 0 ? void 0 : onExtraButtonPress();
      }
    }, extraButtonUI) : /*#__PURE__*/React.createElement(Spacer, {
      width: 20
    })));
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, isVisible ? renderContent() : null);
};
const styles = StyleSheet.create({
  container: {
    padding: st(16),
    backgroundColor: colors.white,
    borderRadius: st(5),
    marginHorizontal: st(6)
  },
  absoluteCenter: {
    position: 'absolute',
    top: '40%',
    alignSelf: 'center'
  },
  absoluteTopCenter: {
    position: 'absolute',
    top: vs(24),
    alignSelf: 'center'
  },
  absoluteBottomCenter: {
    position: 'absolute',
    bottom: vs(24),
    alignSelf: 'center'
  },
  rowContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center'
  },
  text: {
    color: colors.black,
    fontSize: st(12),
    fontWeight: isIOS ? '500' : 'normal',
    textAlign: 'center',
    textAlignVertical: 'center'
  },
  recordLineImage: {
    flex: 1,
    height: vs(24)
  },
  imageTrashBtn: {
    width: st(20),
    height: st(20)
  },
  imageRecordButton: {
    width: st(32),
    height: st(32)
  }
});
export default /*#__PURE__*/forwardRef(RecorderPlayerResponsivePopup);
//# sourceMappingURL=RecorderPlayerResponsiveView.js.map