import React, { useEffect, useRef, useState } from 'react';
import { Keyboard, Linking, ScrollView, StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import DeviceInfo from 'react-native-device-info';
import RemoteStorageModule from '../../services/RemoteStorage/RemoteStorageModule';
import { MindExpressionApiEvents } from '../../MindExpressionApi/MindExpressionApi.type';
import { MindExpressionApi } from '../../MindExpressionApi/MindExpressionApi';
import { DateTimeHelper } from '../../utils';
import ChatList from '../ChatList/ChatList';
const MindAIExpressionChatUI = _ref => {
  var _currentResponse$data;
  let {
    ENGINE_URL,
    AUTH_KEY,
    showLogCheck,
    showError,
    remoteStorageConfig,
    test
  } = _ref;
  //States
  const [mindExpressionAPI, setMindExpressionAPI] = useState();
  const [isStarted, setIsStarted] = useState(false);
  const [message, setMessage] = useState('');
  const [currentResponse, setCurrentResponse] = useState();
  const [messagesHistory, setMessagesHistory] = useState([]);
  const [logs, setLogs] = useState('');
  const [isCheckedLogs, setIsCheckedLogs] = useState(false);

  //Refs
  let flatlistRef = useRef(null);
  //Effects
  useEffect(() => {
    if (remoteStorageConfig && !(RemoteStorageModule !== null && RemoteStorageModule !== void 0 && RemoteStorageModule.getInstance())) {
      RemoteStorageModule.setup(remoteStorageConfig);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  useEffect(() => {
    const listener = mindExpressionAPI === null || mindExpressionAPI === void 0 ? void 0 : mindExpressionAPI.eventEmitter.on(MindExpressionApiEvents.NEW_MESSAGE, data => {
      console.log('new message', data === null || data === void 0 ? void 0 : data.newMessage);
      setMessagesHistory([...(data === null || data === void 0 ? void 0 : data.conversationData), ...((test === null || test === void 0 ? void 0 : test.mockedMessages) ?? [])]);
    });
    return () => {
      var _mindExpressionAPI$ev;
      mindExpressionAPI === null || mindExpressionAPI === void 0 || (_mindExpressionAPI$ev = mindExpressionAPI.eventEmitter) === null || _mindExpressionAPI$ev === void 0 ? void 0 : _mindExpressionAPI$ev.removeListener(MindExpressionApiEvents.NEW_MESSAGE, listener);
    };
  });
  const login = async () => {
    const deviceUniqueId = await DeviceInfo.getUniqueId();
    setMindExpressionAPI(new MindExpressionApi(ENGINE_URL, AUTH_KEY, deviceUniqueId, {
      useLogger: true
    }));
    setIsStarted(false);
    setMessage('');
  };
  const greeting = async () => {
    const res = await (mindExpressionAPI === null || mindExpressionAPI === void 0 ? void 0 : mindExpressionAPI.greeting());
    console.log('start.res:', res);
    setCurrentResponse(res);
    setIsStarted(!!(res !== null && res !== void 0 && res.data));
  };
  const restart = async () => {
    const res = await (mindExpressionAPI === null || mindExpressionAPI === void 0 ? void 0 : mindExpressionAPI.restart());
    console.log('restart.res:', res);
    setCurrentResponse(res);
    setIsStarted(!!(res !== null && res !== void 0 && res.data));
  };
  const converse = async function () {
    var _flatlistRef$current;
    let msg = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : message;
    Keyboard.dismiss();
    setMessage('');
    const res = await (mindExpressionAPI === null || mindExpressionAPI === void 0 ? void 0 : mindExpressionAPI.converse(msg));
    console.log('converse.res:', res);
    setCurrentResponse(res);
    flatlistRef === null || flatlistRef === void 0 || (_flatlistRef$current = flatlistRef.current) === null || _flatlistRef$current === void 0 ? void 0 : _flatlistRef$current.scrollToEnd({
      animated: false
    });
  };
  const handleButtonAction = async btnData => {
    switch (btnData === null || btnData === void 0 ? void 0 : btnData['button-type']) {
      case 'link':
        {
          if (btnData !== null && btnData !== void 0 && btnData.link) {
            Linking.openURL(btnData === null || btnData === void 0 ? void 0 : btnData.link);
          }
          break;
        }
      case 'message':
        {
          if (btnData !== null && btnData !== void 0 && btnData.message) {
            converse(btnData === null || btnData === void 0 ? void 0 : btnData.message);
          }
          break;
        }
    }
  };
  const handleQuickReply = async qrData => {
    if (qrData !== null && qrData !== void 0 && qrData.value) {
      switch (qrData === null || qrData === void 0 ? void 0 : qrData.actionType) {
        case 'link':
          {
            Linking.openURL(qrData === null || qrData === void 0 ? void 0 : qrData.value);
            break;
          }
        case 'message':
        default:
          {
            converse(qrData === null || qrData === void 0 ? void 0 : qrData.value);
            break;
          }
      }
    }
  };
  const handleDateTimeSelect = async (datetime, endDate, pickerProps) => {
    var _datetime$valueOf;
    if (datetime !== null && datetime !== void 0 && (_datetime$valueOf = datetime.valueOf) !== null && _datetime$valueOf !== void 0 && _datetime$valueOf.call(datetime)) {
      const finalStr = DateTimeHelper.formatMindXDatetime(datetime, endDate, pickerProps);
      converse(finalStr);
    }
  };
  const checkLogs = async () => {
    var _mindExpressionAPI$ge;
    Keyboard.dismiss();
    const nLogs = (mindExpressionAPI === null || mindExpressionAPI === void 0 || (_mindExpressionAPI$ge = mindExpressionAPI.getLogs()) === null || _mindExpressionAPI$ge === void 0 ? void 0 : _mindExpressionAPI$ge.join('\n\n')) ?? '';
    setLogs(nLogs);
    setIsCheckedLogs(prev => !prev);
  };
  const renderLogin = () => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: [styles.button, styles.flexEnd],
      onPress: () => {
        login();
      }
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.buttonText
    }, "login"));
  };
  const renderStart = () => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: styles.button,
      onPress: () => {
        greeting();
      }
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.buttonText
    }, "Start"));
  };
  const renderReset = () => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: [styles.button, styles.flexEnd],
      onPress: () => {
        restart();
      }
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.buttonText
    }, "Reset"));
  };
  const renderChat = () => {
    return /*#__PURE__*/React.createElement(ChatList, {
      data: messagesHistory,
      user: {
        _id: 'User'
      },
      keyboardShouldPersistTaps: 'handled',
      onSend: async messages => {
        for (let msg of messages) {
          await converse(msg.text);
        }
      },
      onCardButtonPress: (btnData, _idx) => {
        handleButtonAction(btnData);
      },
      onQuickReplyItemPress: (qrData, _idx) => {
        handleQuickReply(qrData);
      },
      onDateTimeSelect: (datetime, endDate, pickerProps) => {
        handleDateTimeSelect(datetime, endDate, pickerProps);
      }
    });
  };
  const renderHeader = () => {
    return /*#__PURE__*/React.createElement(View, {
      style: styles.header
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.rowContainer
    }, showLogCheck ? /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: [styles.button, styles.flexEnd],
      onPress: () => {
        checkLogs();
      }
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.buttonText
    }, isCheckedLogs ? 'Hide logs' : 'Check Logs')) : /*#__PURE__*/React.createElement(View, null), !mindExpressionAPI ? renderLogin() : !isStarted ? renderStart() : renderReset()), /*#__PURE__*/React.createElement(View, {
      style: styles.verticalSpacer
    }), showLogCheck && isCheckedLogs ? /*#__PURE__*/React.createElement(ScrollView, {
      style: styles.logScrollView
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.logText
    }, logs ? logs : 'No log found!')) : undefined);
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.backgroundStyle
  }, renderHeader(), mindExpressionAPI && isStarted ? renderChat() : undefined, showError && !(currentResponse !== null && currentResponse !== void 0 && (_currentResponse$data = currentResponse.data) !== null && _currentResponse$data !== void 0 && (_currentResponse$data = _currentResponse$data['channel-result']) !== null && _currentResponse$data !== void 0 && _currentResponse$data.length) && currentResponse !== null && currentResponse !== void 0 && currentResponse.description ? /*#__PURE__*/React.createElement(Text, {
    style: styles.errorText
  }, "Error: ", currentResponse === null || currentResponse === void 0 ? void 0 : currentResponse.description) : undefined);
};
const styles = StyleSheet.create({
  flexEnd: {
    alignSelf: 'flex-end'
  },
  backgroundStyle: {
    flex: 1,
    backgroundColor: '#F2F4F5'
  },
  header: {
    paddingHorizontal: 20
  },
  chatContainer: {},
  flatlist: {
    flexGrow: 1,
    height: 400
  },
  button: {
    height: 48,
    borderRadius: 6,
    paddingHorizontal: 20,
    backgroundColor: '#18aa78',
    alignSelf: 'center',
    justifyContent: 'center',
    alignItems: 'center'
  },
  buttonText: {
    fontSize: 16,
    color: '#000',
    textAlign: 'center',
    textAlignVertical: 'center'
  },
  errorText: {
    fontSize: 16,
    color: '#ff0000',
    textAlign: 'center',
    textAlignVertical: 'center',
    alignSelf: 'flex-end',
    marginTop: 10
  },
  logScrollView: {
    height: 100
  },
  logText: {
    fontSize: 12,
    color: '#000',
    textAlign: 'left',
    textAlignVertical: 'center',
    marginBottom: 20,
    alignSelf: 'flex-start'
  },
  rowContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between'
  },
  verticalSpacer: {
    height: 10
  }
});
export default MindAIExpressionChatUI;
//# sourceMappingURL=MindAIExpressionChatUI.js.map