import { FileHelper } from '../../utils';
import { RemoteStorageService } from './RemoteStorageService';
import { BlobServiceClient } from '@azure/storage-blob';
global.Buffer = require('buffer').Buffer;
export class AzureBlobStorageService extends RemoteStorageService {
  constructor(config) {
    super();
    this.storageName = config.storageName;
    this.containerName = config.containerName;
    this.blobServiceClient = new BlobServiceClient(this.buildSASUrl(config.sasToken));
    this.containerClient = this.blobServiceClient.getContainerClient(this.containerName);
    this.createContainer();
  }
  createContainer = async () => {
    // Create the container
    try {
      var _this$containerCreate;
      this.containerCreateResponse = await this.containerClient.create();
      console.log(`Container was created successfully.\n\trequestId:${(_this$containerCreate = this.containerCreateResponse) === null || _this$containerCreate === void 0 ? void 0 : _this$containerCreate.requestId}\n\tURL: ${this.containerClient.url}`);
    } catch (e) {
      console.log(e === null || e === void 0 ? void 0 : e.message);
    }
  };
  uploadFile = async (path, uploadFileName) => {
    try {
      const blob = await FileHelper.uriToBlob(path);

      // Get a block blob client
      const blockBlobClient = this.containerClient.getBlockBlobClient(uploadFileName);

      // Upload data to the blob
      const uploadBlobResponse = await blockBlobClient.upload(blob, blob.size);
      console.log(`Blob was uploaded successfully. requestId: ${uploadBlobResponse.requestId}`);
      return this.buildUploadedUrl(uploadFileName);
    } catch (e) {
      console.log(e);
      return '';
    }
  };

  ///Private functions
  buildStorageUrl = () => {
    const url = `https://${this.storageName}.blob.core.windows.net`;
    return url;
  };
  buildSASUrl = sasToken => {
    const url = `${this.buildStorageUrl()}/${sasToken !== null && sasToken !== void 0 && sasToken.startsWith('?') ? '' : '?'}${sasToken}`;
    return url;
  };
  buildUploadedUrl = fileNameOrPath => {
    const url = `${this.buildStorageUrl()}/${this.containerName}/${fileNameOrPath}`;
    return url;
  };
}
//# sourceMappingURL=AzureBlobStorageService.js.map