import { FileHelper } from '../../utils';
import { RemoteStorageService } from './RemoteStorageService';
import { initializeApp } from 'firebase/app';
import { getStorage, ref, uploadBytesResumable, getDownloadURL } from 'firebase/storage';
export class FirebaseStorageService extends RemoteStorageService {
  constructor(config) {
    super();
    this.app = initializeApp(config.options);
    this.fbStorage = getStorage();
    this.rootPath = this.buildRootPath(config.rootDirectory);
  }
  uploadFile = async (path, uploadFileName) => {
    try {
      const blob = await FileHelper.uriToBlob(path);

      // Reference of file to upload
      const fileRef = ref(this.fbStorage, this.buildFilePath(uploadFileName));
      //Upload the file. Use uploadTask for if we want to control upload in the future
      const uploadTask = uploadBytesResumable(fileRef, blob);
      const result = await uploadTask;
      console.log(result);
      return await getDownloadURL(fileRef);
    } catch (e) {
      console.log(e);
      return '';
    }
  };

  ///Private functions
  buildRootPath = name => {
    // Root is `/`
    if (!name) {
      return '';
    }

    // Root is `/name/`
    if (!name.startsWith('/') && !name.startsWith('\\')) {
      name = '/' + name;
    }
    if (!name.endsWith('/') && !name.endsWith('\\')) {
      name = name + '/';
    }
    return name;
  };
  buildFilePath = fileName => {
    return `${this.rootPath}${fileName}`;
  };
}
//# sourceMappingURL=FirebaseStorageService.js.map