import { ExpressionApi } from '../services/ExpressionApi/ExpressionApi';
import { GatewayResponse } from '../services/ExpressionApi/ExpressionApi.types';
import { ConversationData, MindExpressionApiEvents, MindExpressionApiEventArgs } from './MindExpressionApi.type';
import MyEventEmitter from '../utils/customs/MyEventEmitter';
export declare class MindExpressionApi {
    /**Engine URL - You can get this on the integration page. This is the main URL you will use to access the API’s endpoint*/
    private engineUrl;
    /**Auth Key - This is the authorization token on the integration page. This token is used to authorize your access to the Mind Expression API.*/
    private authKey;
    /**UUID (e.g. 408b6dca-fc5e-4be7-b5a9-cfa9d6c61a3c)*/
    private conversationId;
    /**UUID (e.g. 408b6dca-fc5e-4be7-b5a9-cfa9d6c61a3c)*/
    private currentQueryId;
    /**UUID (e.g. 408b6dca-fc5e-4be7-b5a9-cfa9d6c61a3c)*/
    private xRecipientId;
    /**timestamp(milliseconds) */
    private currentTimestamp;
    /**Splited DEVELOPER_ID from API to use later */
    DEVELOPER_ID: string;
    /**Splited SCOPE_ID from API to use later */
    SCOPE_ID: string;
    /**Instance of API query class */
    expressionApi: ExpressionApi;
    /**Map of chat messages by timestamp */
    conversationDataMap: Map<number, ConversationData>;
    /**Logger to log action events */
    private logger?;
    /** */
    eventEmitter: MyEventEmitter<MindExpressionApiEvents, MindExpressionApiEventArgs[MindExpressionApiEvents]>;
    /**
     * Create a new Mind Expression object
     * @param engineUrl Engine URL - You can get this on the integration page. This is the main URL you will use to access the API’s endpoint
     * @param authKey Auth Key - This is the authorization token on the integration page. This token is used to authorize your access to the Mind Expression API.
     * @param deviceUinqueId Unique id of device- This will be use to save/fetch device chat history
     * @param options options to custom MindExpressionApi:
     *      - useLogger @type {boolean}: log all events or not
     */
    constructor(engineUrl: string, authKey: string, deviceUinqueId?: string, options?: {
        useLogger?: boolean;
    });
    /**
     *
     * Start the Conversation
     * conversationId will always set to null when call function
     * @returns object of @type {GatewayResponse} the response conversation of API
     */
    greeting: () => Promise<GatewayResponse>;
    /**
     *
     * Restart the Conversation
     * @returns object of @type {GatewayResponse} the response conversation of API
     */
    restart: () => Promise<GatewayResponse>;
    converse: (query: string) => Promise<GatewayResponse>;
    getLogs: () => string[];
    resetSession: () => void;
    setSession: (newConversationId?: string | null) => void;
    /**Get latest conversationId. */
    getSession: () => string | null;
    /**Get latest query-id that is sent. */
    getQueryId: () => string | null;
    /**Get latest timestamp sent a request. */
    getTimestamp: () => number | undefined;
    private updateMessageList;
    private updateUserMessage;
    private updateCAIMessages;
    private isValidMessageObject;
}
//# sourceMappingURL=MindExpressionApi.d.ts.map